JustBash.AST.Word (JustBash v0.3.0)

A Word is a sequence of parts that form a single shell word. After expansion, it may produce zero, one, or multiple strings.

Summary

Types

t()

@type t() :: %JustBash.AST.Word{parts: [JustBash.AST.word_part()]}